import unittest
import filecmp
import sys

import schedule_data_processing as sd


class TestCLI(unittest.TestCase):

    def setUp(self):
        sd.init()

    def test_lookup(self):
        assert sd.query(["schedule_data", "lookup", "ZG2362"]) == '{"aircraft_registration": "ZGAUI", "departure_airport": "MCO", "arrival_airport": "FRA", "scheduled_departure_time": "2020-01-01 16:05:00", "scheduled_takeoff_time": "2020-01-01 16:15:00", "scheduled_landing_time": "2020-01-02 00:55:00", "scheduled_arrival_time": "2020-01-02 01:05:00", "flight_number": "ZG2362", "IATATypeDesignator": "789", "TypeName": "Boeing 787-9", "Hub": "FRA", "Haul": "LH", "total_seats": "216", "distance_nm": "4122.69"}'


    def test_lookup_multi(self):
        assert sd.query(["schedule_data", "lookup", "ZG2361,ZG2362"]) == '{"aircraft_registration": "ZGAUI", "departure_airport": "FRA", "arrival_airport": "MCO", "scheduled_departure_time": "2020-01-01 06:20:00", "scheduled_takeoff_time": "2020-01-01 06:30:00", "scheduled_landing_time": "2020-01-01 15:10:00", "scheduled_arrival_time": "2020-01-01 15:20:00", "flight_number": "ZG2361", "IATATypeDesignator": "789", "TypeName": "Boeing 787-9", "Hub": "FRA", "Haul": "LH", "total_seats": "216", "distance_nm": "4122.69"}\n{"aircraft_registration": "ZGAUI", "departure_airport": "MCO", "arrival_airport": "FRA", "scheduled_departure_time": "2020-01-01 16:05:00", "scheduled_takeoff_time": "2020-01-01 16:15:00", "scheduled_landing_time": "2020-01-02 00:55:00", "scheduled_arrival_time": "2020-01-02 01:05:00", "flight_number": "ZG2362", "IATATypeDesignator": "789", "TypeName": "Boeing 787-9", "Hub": "FRA", "Haul": "LH", "total_seats": "216", "distance_nm": "4122.69"}'


    def test_merge(self):
        assert sd.query(["schedule_data", "merge"]) == ""
        assert filecmp.cmp('output_original.csv', 'output.csv')

    def test_lookup_not_found(self):
        assert sd.query(["schedule_data", "lookup", "ZG"]) == '{"error": "Flight number ZG not found."}'

    def test_lookup_not_found_multi(self):
        assert sd.query(["schedule_data", "lookup", "ZG,ZG5001,ZG999"]) == '{"error": "Flight number ZG not found."}\n{"aircraft_registration": "ZGAAA", "departure_airport": "LHR", "arrival_airport": "RAK", "scheduled_departure_time": "2020-01-01 06:45:00", "scheduled_takeoff_time": "2020-01-01 06:55:00", "scheduled_landing_time": "2020-01-01 09:50:00", "scheduled_arrival_time": "2020-01-01 10:00:00", "flight_number": "ZG5001", "IATATypeDesignator": "319", "TypeName": "Airbus A319-100", "Hub": "LHR", "Haul": "SH", "total_seats": "138", "distance_nm": "1237.54"}\n{"error": "Flight number ZG999 not found."}'
